@@ -19,3 +19,5 @@ pub mod navbar;
 pub mod spinner;
 #[cfg(feature = "text")]
 pub mod text;
+#[cfg(feature = "tooltip")]
+pub mod tooltip;
